@@ -111,10 +111,11 @@ macro_rules! try_ {
 // *mut T -> Option<&T> -> Fallible<&T> -> &T
 macro_rules! try_as_ref {
     ($value:expr) => {
-        try_!(crate::util::as_ref($value).ok_or_else(|| opendp::err!(FFI, concat!("null pointer: ", stringify!($value)))));
+        try_!(crate::util::as_ref($value).ok_or_else(|| opendp::err!(FFI, concat!("null pointer: ", stringify!($value)))))
     }
 }
 
+
 #[macro_use]
 mod dispatch;
 
@@ -125,5 +126,6 @@ mod glue;
 mod meas;
 mod trans;
 pub(crate) mod util;
+#[cfg(feature="contrib")]
 mod comb;
 mod accuracy;
